@@ -1,7 +1,8 @@
 """Implements the Mercurial VCS dialect."""
 import os
 
-from uvc.commands import UVCError, DialectCommand, StatusOutput
+from uvc.commands import UVCError, DialectCommand, StatusOutput, BaseCommand
+from uvc.exc import RepositoryAlreadyInitialized
 
 class HgError(UVCError):
     """A Mercurial-dialect specific error."""
@@ -21,6 +22,25 @@ class AuthHgCommand(HgCommand):
                 parts.insert(2, "ssh -i %s -o StrictHostKeyChecking=no" % (auth['key']))
         return parts
 
+class init(HgCommand):
+    reads_remote = False
+    writes_remote = False
+    
+    @classmethod
+    def from_args(cls, context, args):
+        return cls(context, args)
+        
+    def __init__(self, context, args):
+        from uvc import main
+        dialect = main.infer_dialect(context.working_dir)
+        if dialect:
+            raise RepositoryAlreadyInitialized("It looks like there is an %s" 
+                            " repository there" % dialect.name)
+        
+    def command_parts(self):
+        return ['init']
+    
+
 class clone(AuthHgCommand):
     reads_remote = True
     writes_remote = False
@@ -89,6 +109,9 @@ class status(HgCommand):
         return StatusOutput(returncode, stdout)
     
 class HgDialect(object):
+    
+    name = "hg"
+    
     def convert(self, command_object):
         """Converts to a Mercurial-specific command."""
         local_command = self.get_dialect_command_class(command_object.__class__.__name__)
