@@ -2,8 +2,9 @@ import os
 from cStringIO import StringIO
 
 from uvc.path import path
-from uvc import commands, hg, main
+from uvc import commands, hg, main, exc
 from uvc.tests.util import test_context
+from uvc.tests.mock import patch
 
 StatusOutput = commands.StatusOutput
 
@@ -166,4 +167,22 @@ I ignored/file
 [StatusOutput.IGNORED, "ignored/file"]
 ]
     assert str(output) == status_output
+    
+@patch("uvc.main.infer_dialect")
+def test_init_command(infer_dialect):
+    infer_dialect.return_value = None
+    init = hg.init.from_args(test_context, [])
+    assert init.command_parts() == ["init"]
+    assert init.get_command_line() == ["hg", "init"]
+    
+@patch('uvc.main.infer_dialect')
+def test_init_command_in_existing_repo(infer_dialect):
+    infer_dialect.return_value = dialect
+    
+    try:
+        init = hg.init.from_args(test_context, [])
+        assert False, "Should have gotten an exception about existing repo"
+    except exc.RepositoryAlreadyInitialized:
+        pass
+    
     
\ No newline at end of file
